@@ -2,6 +2,7 @@ import click
 import json
 import os
 import requests
+import random
 
 from collections import defaultdict
 from datetime import datetime
@@ -27,6 +28,8 @@ class Alarm:
     def __init__(
         self,
         language="he",
+        highlight=None,
+        reverse=False,
         polling_delay=1,
         routine_delay=60 * 5,
         alarm_id=False,
@@ -38,8 +41,11 @@ class Alarm:
         mqtt_port=1883,
         mqtt_topic="",
         mqtt_filter=None,
+        **_kwargs,
     ):
         self.language = language
+        self.highlight = highlight
+        self.reverse = reverse
         self.polling_delay = polling_delay
         self.last_routine_delay = routine_delay
         self.alarm_id = alarm_id
@@ -119,6 +125,10 @@ class Alarm:
             # empty content means no alarms
             return [], None
 
+        if res.content == b"\xef\xbb\xbf\r\n":
+            # some weird binary content that also means no alarms
+            return [], None
+
         data = {}  # To avoid warning in KeyError
         try:
             data = res.json()
@@ -170,11 +180,18 @@ class Alarm:
     def output_alarms(self, cities, alarm_id):
         areas = self.group_areas_and_localize(cities)
         self.output_leading_timestamp(nl=True)
-        for area, cities in areas.items():
-            cities_str = ", ".join(cities)
-            click.secho(f"\t{area:<20} ", fg="red", bold=True, nl=False)
-            click.secho(f"\t{cities_str} ", fg="red")
+        for area, cities in sorted(areas.items()):
+            bg = "yellow" if self.highlight and self.highlight in area else None
+            click.secho(f"\t{area:<20} ", fg="red", bg=bg, bold=True, nl=False)
+            click.secho("\t", nl=False)
+            for i, city in enumerate(cities):
+                bg = "yellow" if self.highlight and self.highlight in city else None
+                click.secho(f"{city}", fg="red", bg=bg, nl=False)
+                suffix = ", " if i < len(cities) - 1 else ""
+                click.secho(f"{suffix}", fg="red", nl=False)
+            click.secho("")
             if self.desktop_notifications:
+                cities_str = ", ".join(cities)
                 os.system(
                     f'/usr/bin/osascript -e \'display notification "{cities_str}" with title "Alarms at {area}"\''
                 )
@@ -202,15 +219,24 @@ class Alarm:
             labels = self.labels.get(city, {})
             area = labels.get(f"areaname_{self.language}", "")
             label = labels.get(f"label_{self.language}", city)
+            if self.reverse:
+                area = area[::-1]
+                label = label[::-1]
             res[area].append(label)
         return res
 
-    def localize_cities(self, cities):
-        localized_cities = [
-            self.labels.get(city, {}).get(f"label_{self.language}", city)
-            for city in cities
-        ]
-        return ", ".join(localized_cities)
+    def output_test(self):
+        self.output_error("Output test started...")
+        self.output_routine()
+        alarms = random.sample(list(self.labels.keys()), 8)
+        self.output_alarms(alarms, 9999)
+        self.output_routine()
+        self.highlight = "ה" if self.language == "he" else "s"
+        alarms = random.sample(list(self.labels.keys()), 10)
+        self.output_alarms(alarms, 9999)
+        self.output_routine()
+        self.output_routine()
+        self.output_error("Output test complete, exiting.")
 
 
 @click.command()
@@ -220,6 +246,15 @@ class Alarm:
     type=click.Choice(["en", "he", "ar", "ru"]),
     help="Alert language",
 )
+@click.option(
+    "--highlight",
+    help="String to search for and highlight in case of alarm",
+)
+@click.option(
+    "--reverse",
+    is_flag=True,
+    help="Reverse Hebrew/Arabic output for terminals with RTL bugs",
+)
 @click.option("--polling-delay", default=1, help="Polling delay in seconds")
 @click.option(
     "--routine-delay", default=60 * 5, help="Routine message delay in seconds"
@@ -227,6 +262,11 @@ class Alarm:
 @click.option("--alarm-id", is_flag=True, help="Print alarm IDs")
 @click.option("--repeat-alarms", is_flag=True, help="Do not suppress ongoing alarms")
 @click.option("--quiet", is_flag=True, help="Print only active alarms")
+@click.option(
+    "--desktop-notifications",
+    is_flag=True,
+    help="Create push notifications on your desktop notification center (currently only in Mac OS)",
+)
 @click.option(
     "--mqtt-server", default=None, help="Hostname / IP of MQTT server (optional)"
 )
@@ -241,12 +281,16 @@ class Alarm:
     help="Payload value to filter before sending as a message (semicolon separated)",
 )
 @click.option(
-    "--desktop-notifications",
+    "--output-test",
     is_flag=True,
-    help="Create push notifications on your desktop notification center (currently only in Mac OS)",
+    help="Print a debug output and exit",
 )
 def cli(**kwargs):
-    Alarm(**kwargs).start()
+    alarm = Alarm(**kwargs)
+    if kwargs["output_test"]:
+        alarm.output_test()
+    else:
+        alarm.start()
 
 
 if __name__ == "__main__":
